@@ -1,12 +1,12 @@
 //! Simple inmemory stream.
 //!
-//! Created for use as a buffer. Supports write, peek, read operations.
+//! Created for use as a buffer. Supports write, peek, read, skip operations.
 //!
 //! # Examples
 //!
 //! ### Write, read stream.
 //! ```
-//! use stream_inmemory::Stream;
+//! use stream_inmemory::{Stream, TWrite, TRead};
 //! let arr = [1, 2, 3, 4, 5, 6, 7, 8, 9];
 //! let mut stream = Stream::new();
 //! stream.write(&arr[2..6]);
@@ -19,11 +19,11 @@
 //! ```
 //!
 
+mod traits;
 mod stream;
-mod utils;
 
 #[cfg(test)]
 mod tests;
 
 pub use stream::{Stream, StreamError};
-pub use utils::{Reader, Writer};
\ No newline at end of file
+pub use traits::{TRead, TWrite};
\ No newline at end of file
