@@ -1,4 +1,5 @@
 use crate::{Stream};
+use crate::traits::{TWrite, TRead};
 
 #[test]
 fn it_works() {
@@ -8,6 +9,8 @@ fn it_works() {
     assert_eq!(stream.available(), 4);
     let mut dest = [0; 10];
     stream.read(&mut dest).ok();
+    stream.truncate_readied();
+    stream.truncate_capacity();
     assert_eq!(dest, [3, 4, 5, 6, 0, 0, 0, 0, 0, 0]);
     assert_eq!(stream.available(), 0);
     assert_eq!(2 + 2, 4);
